.. _config_reference:

Configuration Reference
============================

This document lists all options for the inmanta server and inmanta agent.

The options are listed per config section.

.. show-options::

    inmanta.deploy
    inmanta.export
    inmanta.server.config
    inmanta.agent.config
    inmanta.compiler.config
